.. hwit-core documentation master file, created by
   sphinx-quickstart on Mon May 14 14:35:54 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

..  Titling
    ##++::==~~--''``

Hwit-core manual
================

Contents:

.. toctree::
   :maxdepth: 2

   hwit-dev
   hwit-spec

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

